diff --git a/src/backend/commands/collationcmds.c b/src/backend/commands/collationcmds.c
index 919e092483..ad011d149c 100644
--- a/src/backend/commands/collationcmds.c
+++ b/src/backend/commands/collationcmds.c
@@ -36,6 +36,10 @@
 #include "utils/syscache.h"
 
 
+#ifdef USE_ICU
+static char *get_icu_locale_comment(const char *localename);
+#endif
+
 typedef struct
 {
 	char	   *localename;		/* name of locale, as per "locale -a" */
@@ -232,6 +236,16 @@ DefineCollation(ParseState *pstate, List *names, List *parameters, bool if_not_e
 	if (!OidIsValid(newoid))
 		return InvalidObjectAddress;
 
+#ifdef USE_ICU
+	if (collprovider == COLLPROVIDER_ICU)
+	{
+		char *display_name = get_icu_locale_comment(collcollate);
+		if (display_name != NULL)
+			ereport(NOTICE,
+					(errmsg("ICU locale: \"%s\"", display_name)));
+	}
+#endif
+
 	/*
 	 * Check that the locales can be loaded.  NB: pg_newlocale_from_collation
 	 * is only supposed to be called on non-C-equivalent locales.
